@@ -1,3 +1,11 @@
+/* os_dep.h
+ * (c) 2002 Mikulas Patocka
+ * This file is a part of the Links program, released under GPL.
+ */
+
+#ifndef OS_DEP_H
+#define OS_DEP_H
+
 #define SYS_UNIX	1
 #define SYS_OS2		2
 #define SYS_WIN_32	3
@@ -7,6 +15,8 @@
 #define SYS_SPAD	7
 #define SYS_INTERIX	8
 #define SYS_OPENVMS	9
+#define SYS_DOS		10
+#define SYS_HAIKU	11
 
 /* hardcoded limit of 10 OSes in default.c */
 
@@ -17,10 +27,10 @@
 #if defined(__EMX__)
 #define OS2
 #elif defined(_WIN32) || defined(__CYGWIN__)
-#define WIN32
+#define WIN
 #elif defined(__INTERIX)
 #define INTERIX
-#elif defined(__BEOS__) || defined(__HAIKU__)
+#elif defined(__BEOS__)
 #define BEOS
 #elif defined(__riscos__)
 #define RISCOS
@@ -30,13 +40,17 @@
 #define SPAD
 #elif defined(__VMS)
 #define OPENVMS
+#elif defined(__DJGPP)
+#define DOS
+#elif defined(__HAIKU__)
+#define HAIKU
 #else
 #define UNIX
 #endif
 
 #if defined(UNIX)
 
-static inline int dir_sep(char x) { return x == '/'; }
+static inline int dir_sep(unsigned char x) { return x == '/'; }
 #define NEWLINE "\n"
 #define FS_UNIX_RIGHTS
 #define FS_UNIX_HARDLINKS
@@ -49,15 +63,13 @@ static inline int dir_sep(char x) { return x == '/'; }
 #define SHARED_CONFIG_DIR "/etc/"
 #ifdef HAVE_SYS_UN_H
 #define USE_AF_UNIX
-#else
-#define DONT_USE_AF_UNIX
 #endif
 #define ASSOC_BLOCK
 #define ASSOC_CONS_XWIN
 
 #elif defined(OS2)
 
-static inline int dir_sep(char x) { return x == '/' || x == '\\'; }
+static inline int dir_sep(unsigned char x) { return x == '/' || x == '\\'; }
 #define NEWLINE "\r\n"
 /*#define NO_ASYNC_LOOKUP*/
 #define SYSTEM_ID SYS_OS2
@@ -70,12 +82,13 @@ static inline int dir_sep(char x) { return x == '/' || x == '\\'; }
 #define DOS_FS_8_3
 #define NO_FILE_SECURITY
 #define NO_FORK_ON_EXIT
+#define USE_AF_UNIX
 #define ASSOC_CONS_XWIN
 #define DISABLE_SMB
 
-#elif defined(WIN32)
+#elif defined(WIN)
 
-static inline int dir_sep(char x) { return x == '/' || x == '\\'; }
+static inline int dir_sep(unsigned char x) { return x == '/' || x == '\\'; }
 #define NEWLINE "\r\n"
 /*#define NO_ASYNC_LOOKUP*/
 #define SYSTEM_ID SYS_WIN_32
@@ -87,9 +100,7 @@ static inline int dir_sep(char x) { return x == '/' || x == '\\'; }
 #define DOS_FS
 #define SET_WINDOW_TITLE_UTF_8
 #define ASSOC_CONS_XWIN
-#ifdef _UWIN
 #define DISABLE_SMB
-#endif
 #ifdef __CYGWIN__
 #define OS_BAD_SIGNALS
 #endif
@@ -98,13 +109,20 @@ static inline int dir_sep(char x) { return x == '/' || x == '\\'; }
 #endif
 #if defined(HAVE_SYS_UN_H) && !defined(_UWIN)
 #define USE_AF_UNIX
-#else
-#define DONT_USE_AF_UNIX
+#endif
+#if defined(_UWIN)
+#define USE_WIN32_HEAP
+#endif
+#ifdef USE_WIN32_HEAP
+#define NO_FORK_ON_EXIT
+#endif
+#ifndef __CYGWIN__
+#define OS_NO_SYSTEM_CHARSET
 #endif
 
 #elif defined(INTERIX)
 
-static inline int dir_sep(char x) { return x == '/'; }
+static inline int dir_sep(unsigned char x) { return x == '/'; }
 #define NEWLINE "\n"
 #define FS_UNIX_RIGHTS
 #define FS_UNIX_HARDLINKS
@@ -117,15 +135,14 @@ static inline int dir_sep(char x) { return x == '/'; }
 #define SHARED_CONFIG_DIR "/etc/"
 #ifdef HAVE_SYS_UN_H
 #define USE_AF_UNIX
-#else
-#define DONT_USE_AF_UNIX
 #endif
 #define ASSOC_BLOCK
 #define ASSOC_CONS_XWIN
+#define OS_NO_SYSTEM_CHARSET
 
 #elif defined(BEOS)
 
-static inline int dir_sep(char x) { return x == '/'; }
+static inline int dir_sep(unsigned char x) { return x == '/'; }
 #define NEWLINE "\n"
 #define NO_ASYNC_LOOKUP /* async lookup works on BeOS but crashes the Haiku kernel */
 #define FS_UNIX_RIGHTS
@@ -138,7 +155,10 @@ static inline int dir_sep(char x) { return x == '/'; }
 #define NO_CTRL_Z
 #define SHARED_CONFIG_DIR "/etc/"
 #define NO_FORK_ON_EXIT
+#define USE_AF_UNIX
 #define ASSOC_BLOCK
+#define OS_NO_SYSTEM_CHARSET
+#define OS_NO_SYSTEM_LANGUAGE
 
 #include <sys/time.h>
 #include <sys/types.h>
@@ -147,35 +167,28 @@ static inline int dir_sep(char x) { return x == '/'; }
 #endif
 #include <sys/socket.h>
 
-int be_socket(int, int, int);
-int be_connect(int, struct sockaddr *, int);
-int be_getpeername(int, struct sockaddr *, int *);
-int be_getsockname(int, struct sockaddr *, int *);
-int be_listen(int, int);
-int be_accept(int, struct sockaddr *, int *);
-int be_bind(int, struct sockaddr *, int);
-int be_pipe(int *);
-int be_read(int, void *, int);
-int be_write(int, void *, int);
-int be_close(int);
-int be_select(int, struct fd_set *, struct fd_set *, struct fd_set *, struct timeval *);
-int be_getsockopt(int, int, int, void *, int *);
+#include "beos.h"
 
 #elif defined(RISCOS)
 
-static inline int dir_sep(char x) { return x == '/' || x == '\\'; }
-#define NEWLINE        "\n"
+static inline int dir_sep(unsigned char x) { return x == '/' || x == '\\'; }
+#define NEWLINE "\n"
 #define SYSTEM_ID SYS_RISCOS
 #define SYSTEM_NAME "RISC OS"
 #define DEFAULT_SHELL "gos"
 #define GETSHELL getenv("SHELL")
 #define NO_FG_EXEC
+#define NO_CTRL_Z
 #define NO_FILE_SECURITY
 #define NO_FORK_ON_EXIT
+#define USE_AF_UNIX
+#define DISABLE_SMB
+#define OS_NO_SYSTEM_CHARSET
+#define OS_NO_SYSTEM_LANGUAGE
 
 #elif defined(ATHEOS)
 
-static inline int dir_sep(char x) { return x == '/'; }
+static inline int dir_sep(unsigned char x) { return x == '/'; }
 #define NEWLINE "\n"
 #define FS_UNIX_RIGHTS
 #define FS_UNIX_HARDLINKS
@@ -186,11 +199,12 @@ static inline int dir_sep(char x) { return x == '/'; }
 #define DEFAULT_SHELL "/bin/sh"
 #define GETSHELL getenv("SHELL")
 #define SHARED_CONFIG_DIR "/etc/"
+#define NO_FORK_ON_EXIT
 #define ASSOC_BLOCK
 
 #elif defined(SPAD)
 
-static inline int dir_sep(char x) { return x == '/'; }
+static inline int dir_sep(unsigned char x) { return x == '/'; }
 #define NEWLINE "\n"
 #define SYSTEM_ID SYS_SPAD
 #define SYSTEM_NAME "Spad"
@@ -198,14 +212,11 @@ static inline int dir_sep(char x) { return x == '/'; }
 #define GETSHELL "LIB.:/SHELL.EXE"
 #define NO_CTRL_Z
 #define SHARED_CONFIG_DIR "ETC.:/"
-#ifdef HAVE_SYS_UN_H
-#define USE_AF_UNIX
-#else
-#define DONT_USE_AF_UNIX
-#endif
+#define NO_FORK_ON_EXIT
 #define ASSOC_BLOCK
 #define ASSOC_CONS_XWIN
-#define NO_FORK_ON_EXIT
+#define OS_NO_SYSTEM_CHARSET
+#define OS_NO_SYSTEM_LANGUAGE
 
 #elif defined(OPENVMS)
 
@@ -220,12 +231,47 @@ static inline int dir_sep(unsigned char x) { return x == '/'; }
 #ifndef HAVE_PTHREADS
 #define HAVE_PTHREADS
 #endif
-#define DONT_USE_AF_UNIX
-#define ASSOC_BLOCK
-#define ASSOC_CONS_XWIN
 #define NO_CTRL_Z
 #define NO_FORK_ON_EXIT
+#define ASSOC_BLOCK
+#define ASSOC_CONS_XWIN
 #define DISABLE_SMB
+#define OS_NO_SYSTEM_CHARSET
+#define OS_NO_SYSTEM_LANGUAGE
+
+#elif defined(DOS)
+
+static inline int dir_sep(unsigned char x) { return x == '/' || x == '\\'; }
+#define NEWLINE "\r\n"
+#define NO_ASYNC_LOOKUP
+#define SYSTEM_ID SYS_DOS
+#define SYSTEM_NAME "DOS"
+#define DEFAULT_SHELL "command.com"
+#define GETSHELL getenv("COMSPEC")
+#define SHARED_CONFIG_DIR "/dev/env/DJDIR/etc"
+#define NO_CTRL_Z
+#define DOS_FS
+#define DOS_FS_8_3
+#define NO_FILE_SECURITY
+#define NO_FORK_ON_EXIT
+#define DISABLE_SMB
+
+#elif defined(HAIKU)
+
+static inline int dir_sep(unsigned char x) { return x == '/'; }
+#define NEWLINE "\n"
+#define FS_UNIX_RIGHTS
+#define FS_UNIX_SOFTLINKS
+#define FS_UNIX_USERS
+#define SYSTEM_ID SYS_HAIKU
+#define SYSTEM_NAME "Haiku"
+#define DEFAULT_SHELL "/bin/sh"
+#define GETSHELL getenv("SHELL")
+#define NO_CTRL_Z
+#define SET_WINDOW_TITLE_UTF_8
+#define SHARED_CONFIG_DIR "/etc/"
+#define USE_AF_UNIX
+#define ASSOC_BLOCK
 
 #endif
 
@@ -235,3 +281,4 @@ static inline int dir_sep(unsigned char x) { return x == '/'; }
 #endif
 #endif
 
+#endif /* #ifndef OS_DEP_H */
